@@ -16,7 +16,7 @@ IMDB::Local - Tools to dowload and manage a local copy of the IMDB list files in
 
 =cut
 
-our $VERSION = '1.4';
+our $VERSION = '1.5';
 
 =head1 SYNOPSIS
 
@@ -51,6 +51,7 @@ use constant Have_bar => eval {
 };
 
 use IMDB::Local::DB;
+use IMDB::Local::QualifierType ':types';
 
 =head2 new
 
@@ -237,9 +238,9 @@ sub decodeImdbKey($$$)
 	    #}
 	}
  	# "EastEnders" (1985) {(1991-10-15)}                      1991
-	elsif ( $s=~s/^\((\d\d\d\d)\-(\d\d)\-(\d\d)\)$// ) {
+	elsif ( $s=~m/^\((\d\d\d\d)\-(\d\d)\-(\d\d)\)$/ ) {
 	    $hash{airdate}=int("$1$2$3");
-
+	    $hash{title}=$s;
 	}
 	else {
 	    $hash{title}=$s;
@@ -261,36 +262,36 @@ sub decodeImdbKey($$$)
     if ( $dbkey=~s/^\"//o && $dbkey=~s/\" \(/ \(/o) {
 	if ( $dbkey=~s/\s+\(mini\)$//o ) {
 	    if ( $hash{parentId} == 0 ) {
-		$hash{qualifier}=$self->{QualifierTypeIDs}->{"tv_mini_series"};
+		$hash{qualifier}=IMDB::Local::QualifierType::TV_MINI_SERIES;
 		$self->{seriesKeys}->{$dbkey}=$titleID;
 	    }
 	    else {
-		$hash{qualifier}=$self->{QualifierTypeIDs}->{"episode_of_tv_mini_series"};
+		$hash{qualifier}=IMDB::Local::QualifierType::EPISODE_OF_TV_MINI_SERIES
 	    }
 	}
 	else {
 	    if ( $hash{parentId} == 0 ) {
-		$hash{qualifier}=$self->{QualifierTypeIDs}->{"tv_series"};
+		$hash{qualifier}=IMDB::Local::QualifierType::TV_SERIES;
 		$self->{seriesKeys}->{$dbkey}=$titleID;
 	    }
 	    else {
-		$hash{qualifier}=$self->{QualifierTypeIDs}->{"episode_of_tv_series"};
+		$hash{qualifier}=IMDB::Local::QualifierType::EPISODE_OF_TV_SERIES;
 	    }
 	}
     }
     elsif ( $dbkey=~s/\s+\(TV\)$//o ) {
 	# how rude, some entries have (TV) appearing more than once.
 	#$dbkey=~s/\s*\(TV\)$//o;
-	$hash{qualifier}=$self->{QualifierTypeIDs}->{"tv_movie"};
+	$hash{qualifier}=IMDB::Local::QualifierType::TV_MOVIE;
     }
     elsif ( $dbkey=~s/\s+\(V\)$//o ) {
-	$hash{qualifier}=$self->{QualifierTypeIDs}->{"video_movie"};
+	$hash{qualifier}=IMDB::Local::QualifierType::VIDEO_MOVIE;
     }
     elsif ( $dbkey=~s/\s+\(VG\)$//o ) {
-	$hash{qualifier}=$self->{QualifierTypeIDs}->{"video_game"};
+	$hash{qualifier}=IMDB::Local::QualifierType::VIDEO_GAME;
     }
     else {
-	$hash{qualifier}=$self->{QualifierTypeIDs}->{"movie"};
+	$hash{qualifier}=IMDB::Local::QualifierType::MOVIE;
     }
     
     #if ( $dbkey=~s/\s+\((tv_series|tv_mini_series|tv_movie|video_movie|video_game)\)$//o ) {
@@ -340,8 +341,10 @@ sub decodeImdbKey($$$)
     $title=~s/(.*),\s*(The|A|Une|Las|Les|Los|L\'|Le|La|El|Das|De|Het|Een)$/$2 $1/og;
 
     # leave searchtitle empty for tv series'
-    if ( $hash{series} != 0 || $hash{airdate} != 0 ) {
-	$hash{searchTitle}='';
+    if( $hash{qualifier} == IMDB::Local::QualifierType::EPISODE_OF_TV_SERIES ||
+	$hash{qualifier} == IMDB::Local::QualifierType::EPISODE_OF_TV_MINI_SERIES ) {
+	#$hash{title}=$title;
+	$hash{searchTitle}=$DB->makeSearchableTitle($hash{title}, 0);;
     }
     else {
 	if ( !defined($hash{title}) ) {
@@ -401,9 +404,6 @@ sub importMovies($$$$)
     $progress->max_update_rate(1) if ($self->{showProgressBar});
     my $next_update=0;
 
-    # preload qualifier types
-    $self->{QualifierTypeIDs}=$DB->select2Hash("select Name, QualifierTypeID from QualifierTypes");
-
     #$DB->runSQL("BEGIN TRANSACTION");
 
     my $count=0;
@@ -448,8 +448,6 @@ sub importMovies($$$$)
 	    
 	    my $mkey=substr($line, 0, $tab);
 
-	    # lets not import video games
-	    #if ( $decoded->{qualifier} != $self->{QualifierTypeIDs}->{'video_game'} ) {
 	    # returned count is number of titles found
 	    $count++;
 
@@ -537,9 +535,6 @@ sub importGenres($$$$)
     $progress->max_update_rate(1) if ($self->{showProgressBar});
     my $next_update=0;
 
-    # preload qualifier types
-    $self->{QualifierTypeIDs}=$DB->select2Hash("select Name, QualifierTypeID from QualifierTypes");
-
     #$DB->runSQL("BEGIN TRANSACTION");
 
     my $count=0;
